import { LanguageEnum } from '../../../language';
import { HTTPRequest } from '../../../request';
import { IZZZCharacterFull, IZZZShiyuDefense, IZZZNote, IZZZRecord, IZZZDeadlyAssault } from './interfaces';
import { ShiyuDefenseScheduleEnum, DeadlyAssaultScheduleEnum } from './record.enum';
/**
 * ZZZRecordModule class provides methods to interact with Honkai Star Rail record module endpoints.
 *
 * @class
 * @internal
 * @category Module
 */
export declare class ZZZRecordModule {
    private request;
    private lang;
    private region;
    private uid;
    /**
     * Creates an instance of ZZZRecordModule.
     *
     * @param request The HTTPRequest object used for making API requests.
     * @param lang The language enum value.
     * @param region The region string or null if not provided.
     * @param uid The UID number or null if not provided.
     */
    constructor(request: HTTPRequest, lang: LanguageEnum, region: string | null, uid: number | null);
    /**
     * Retrieves the characters associated with the provided region and UID.
     *
     * @returns {Promise<IZZZCharacterFull[]>} A Promise that resolves to an array of full ZZZ characters.
     * @throws {HoyoAPIError} if the region or UID parameters are missing or failed to be filled.
     * @throws {HoyoAPIError} if failed to retrieve data, please double-check the provided UID.
     */
    characters(): Promise<IZZZCharacterFull[]>;
    /**
     * Retrieves the character associated with the provided region and UID.
     *
     * @param characterId Character ID to retrieve.
     * @returns {Promise<IZZZCharacterFull>} A Promise that resolves to a ZZZ character.
     * @throws {HoyoAPIError} if the region or UID parameters are missing or failed to be filled.
     * @throws {HoyoAPIError} if the character ID parameter is missing or failed to be filled.
     * @throws {HoyoAPIError} if failed to retrieve data, please double-check the provided UID.
     */
    character(characterId: number): Promise<IZZZCharacterFull>;
    /**
     * Retrieves the records associated with the provided region and UID.
     *
     * @returns {Promise<IZZZRecord>} A Promise that resolves to the ZZZ record object.
     * @throws {HoyoAPIError} if the region or UID parameters are missing or failed to be filled.
     * @throws {HoyoAPIError} if failed to retrieve data, please double-check the provided UID.
     */
    records(): Promise<IZZZRecord>;
    /**
     * Retrieves the note associated with the provided region and UID.
     *
     * @returns {Promise<IZZZNote>} A Promise that resolves to the ZZZ note object.
     * @throws {HoyoAPIError} if the region or UID parameters are missing or failed to be filled.
     * @throws {HoyoAPIError} if failed to retrieve data, please double-check the provided UID.
     */
    note(): Promise<IZZZNote>;
    /**
     * Retrieves the shiyu defense information associated with the provided region and UID.
     *
     * @param scheduleType The schedule type for the shiyu defense (optional, defaults to CURRENT).
     * @returns {Promise<IZZZShiyuDefense>} A Promise that resolves to the shiyu defense information object.
     * @throws {HoyoAPIError} if the region or UID parameters are missing or failed to be filled.
     * @throws {HoyoAPIError} if the given scheduleType parameter is invalid.
     * @throws {HoyoAPIError} if failed to retrieve data, please double-check the provided UID.
     */
    shiyuDefense(scheduleType?: ShiyuDefenseScheduleEnum): Promise<IZZZShiyuDefense>;
    /**
    * Retrieves the deadly assault information associated with the provided region and UID.
    *
    * @param scheduleType The schedule type for the deadly assault (optional, defaults to CURRENT).
    * @returns {Promise<IZZZDeadlyAssault>} A Promise that resolves to the deadly assault information object.
    * @throws {HoyoAPIError} if the region or UID parameters are missing or failed to be filled.
    * @throws {HoyoAPIError} if the given scheduleType parameter is invalid.
    * @throws {HoyoAPIError} if failed to retrieve data, please double-check the provided UID.
    */
    deadlyAssault(scheduleType?: DeadlyAssaultScheduleEnum): Promise<IZZZDeadlyAssault>;
}
